==> 0.6.2.zip: goober-ionic/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.  

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/).  

## [0.6.2] -
### Fixed
- Missing status bar when app is loaded

### Changed
- Updated android platform requirements
- Updated project dependencies

## [0.6.1] - 2018-02-14
### Fixed
- Login using multi-factor authentication

## [0.6.0] - 2018-02-24
### Added
- Convert posts exceeding 254 characters to long post format
- File uploads

### Changed
- Updated project dependencies
- Display login page when required scope changes

### Fixed
- Handle invalid auth tokens

## [0.5.0] - 2018-01-19
### Added
- Option to select default timeline
- Render long posts in timeline
- Share posts outside of Goober

### Fixed
- Authentication on Kindle Fire OS
- Extraneous / being tacked onto individual replies
- Handle white transparent avatars like @c does
- Missing overflow menu in conversation view

## [0.4.0] - 2017-08-05
### Added
- Ability to delete posts
- Settings page
- Option for unified timeline
- Option to cc on a reply-all

### Fixed
- Bookmarks and reposts from conversation view
- Hyperlinks in conversation view
- Deleted posts showing as empty in timeline
- Self mention on replies

## [0.3.0] - 2017-07-09
### Added
- Toast resposnes when completing actions (post, repost, bookmark)
- Highlight posts mentioning you

### Changed
- Updated oauth workflow to work with other device platforms
- Updated order of menu and action buttons

### Fixed
- Show reposts from originator

## [0.2.0] - 2017-06-20
### Added
- Mentions page
- Bookmarks page
- Character count on new post form

### Fixed
- Post format
- Make hyperlinks active
- New post window size
- Cleaned up login page

## [0.1.1] - 2017-06-11
### Fixed
- Focus cursor on text area when composing a post or reply
- Enable spell check and auto complete

## [0.1.0] - 2017-06-11
### Added
- Intial pre-release for Android

[0.6.2]: https://code.monkeystew.net/thrrgilag/Goober/src/Goober_0_6_2
[0.6.1]: https://code.monkeystew.net/thrrgilag/Goober/src/Goober_0_6_1
[0.6.0]: https://code.monkeystew.net/thrrgilag/Goober/src/Goober_0_6_0
[0.5.0]: https://code.monkeystew.net/thrrgilag/Goober/src/Goober_0_5_0
[0.4.0]: https://code.monkeystew.net/thrrgilag/Goober/src/Goober_0_4_0
[0.3.0]: https://code.monkeystew.net/thrrgilag/Goober/src/Goober_0_3_0
[0.2.0]: https://code.monkeystew.net/thrrgilag/Goober/src/Goober_0_2_0
[0.1.1]: https://code.monkeystew.net/thrrgilag/Goober/src/Goober_0_1_1
[0.1.0]: https://code.monkeystew.net/thrrgilag/Goober/src/Goober_0_1_0

==> 0.6.3.zip: goober-ionic/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.  

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/).  

## [Unreleased]

## [0.6.3]
### Added
- Open post in browser window

### Changed
- Embedded images show thumbnail by default
- Tapping or clicking an image opens source up in browser

### Removed
- Unused cordova plugins for keyboard, console, and statusbar

## [0.6.2] - 2018-05-07
### Fixed
- Missing status bar when app is loaded

### Changed
- Updated android platform requirements
- Updated project dependencies

## [0.6.1] - 2018-02-14
### Fixed
- Login using multi-factor authentication

## [0.6.0] - 2018-02-24
### Added
- Convert posts exceeding 254 characters to long post format
- File uploads

### Changed
- Updated project dependencies
- Display login page when required scope changes

### Fixed
- Handle invalid auth tokens

## [0.5.0] - 2018-01-19
### Added
- Option to select default timeline
- Render long posts in timeline
- Share posts outside of Goober

### Fixed
- Authentication on Kindle Fire OS
- Extraneous / being tacked onto individual replies
- Handle white transparent avatars like @c does
- Missing overflow menu in conversation view

## [0.4.0] - 2017-08-05
### Added
- Ability to delete posts
- Settings page
- Option for unified timeline
- Option to cc on a reply-all

### Fixed
- Bookmarks and reposts from conversation view
- Hyperlinks in conversation view
- Deleted posts showing as empty in timeline
- Self mention on replies

## [0.3.0] - 2017-07-09
### Added
- Toast resposnes when completing actions (post, repost, bookmark)
- Highlight posts mentioning you

### Changed
- Updated oauth workflow to work with other device platforms
- Updated order of menu and action buttons

### Fixed
- Show reposts from originator

## [0.2.0] - 2017-06-20
### Added
- Mentions page
- Bookmarks page
- Character count on new post form

### Fixed
- Post format
- Make hyperlinks active
- New post window size
- Cleaned up login page

## [0.1.1] - 2017-06-11
### Fixed
- Focus cursor on text area when composing a post or reply
- Enable spell check and auto complete

## [0.1.0] - 2017-06-11
### Added
- Intial pre-release for Android

[Unreleased]: https://gitlab.dreamfall.space/thrrgilag/Goober/compare/0.6.3...HEAD
[0.6.3]: https://gitlab.dreamfall.space/thrrgilag/Goober/tags/0.6.3
[0.6.2]: https://gitlab.dreamfall.space/thrrgilag/Goober/tags/Goober_0_6_2
[0.6.1]: https://gitlab.dreamfall.space/thrrgilag/Goober/tags/Goober_0_6_1
[0.6.0]: https://gitlab.dreamfall.space/thrrgilag/Goober/tags/Goober_0_6_0
[0.5.0]: https://gitlab.dreamfall.space/thrrgilag/Goober/tags/Goober_0_5_0
[0.4.0]: https://gitlab.dreamfall.space/thrrgilag/Goober/tags/Goober_0_4_0
[0.3.0]: https://gitlab.dreamfall.space/thrrgilag/Goober/tags/Goober_0_3_0
[0.2.0]: https://gitlab.dreamfall.space/thrrgilag/Goober/tags/Goober_0_2_0
[0.1.1]: https://gitlab.dreamfall.space/thrrgilag/Goober/tags/Goober_0_1_1
[0.1.0]: https://gitlab.dreamfall.space/thrrgilag/Goober/tags/Goober_0_1_0
